package com.mdd.admin.controller.channel;

import com.mdd.admin.service.IChannelOaReplyFollowService;
import com.mdd.admin.validate.channel.ChannelRpFollowsValidate;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.channel.ChannelRpFollowsVo;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/channel/oaReplyFollow"})
@Api(
   tags = {"公众号关注回复"}
)
public class ChannelOaReplyFollowController {
   @Resource
   IChannelOaReplyFollowService iChannelOaReplyFollowService;

   @GetMapping({"/list"})
   @ApiOperation("关注回复列表")
   public AjaxResult<PageResult<ChannelRpFollowsVo>> list(@Validated PageValidate pageValidate) {
      PageResult<ChannelRpFollowsVo> list = this.iChannelOaReplyFollowService.list(pageValidate);
      return AjaxResult.success(list);
   }

   @GetMapping({"/detail"})
   @ApiOperation("关注回复详情")
   public AjaxResult<ChannelRpFollowsVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      ChannelRpFollowsVo vo = this.iChannelOaReplyFollowService.detail(id);
      return AjaxResult.success(vo);
   }

   @PostMapping({"/add"})
   @ApiOperation("关注回复新增")
   public AjaxResult<Object> add(@Validated @RequestBody ChannelRpFollowsValidate followsValidate) {
      this.iChannelOaReplyFollowService.add(followsValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/edit"})
   @ApiOperation("关注回复编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody ChannelRpFollowsValidate followsValidate) {
      this.iChannelOaReplyFollowService.edit(followsValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/del"})
   @ApiOperation("关注回复删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iChannelOaReplyFollowService.del(idValidate.getId());
      return AjaxResult.success();
   }

   @PostMapping({"/status"})
   @ApiOperation("关注回复状态")
   public AjaxResult<Object> status(@Validated @RequestBody IdValidate idValidate) {
      this.iChannelOaReplyFollowService.status(idValidate.getId());
      return AjaxResult.success();
   }
}
